@@ -39,9 +39,10 @@ def download(model=None):
         "/data/doc2vec/model_1200_800_40.h5":"https://www.dropbox.com/s/ooqavntcjia3ery/model_1200_800_40.h5?dl=1",
         "/data/doc2vec/doc2vec_model":"https://www.dropbox.com/s/hk4snqw43adxcog/doc2vec_model?dl=1",
         "/data/doc2vec/doc2vec_model.trainables.syn1neg.npy":"https://www.dropbox.com/s/7w9sv4bc7vuv30b/doc2vec_model.trainables.syn1neg.npy?dl=1",
+        "/data/doc2vec/doc2vec_model.wv.vectors.npy":"https://www.dropbox.com/s/f2p3gp7v06qttc8/doc2vec_model.wv.vectors.npy?dl=1",
         # gpt2 model
-        "/data/gpt2/model_gpt2.h5":"https://www.dropbox.com/s/li3cu3epgbneemu/model_gpt2.h5?dl=1",
-        "/data/gpt2/labelsdict.p":"https://www.dropbox.com/s/d59odrsmawmhgt8/labelsdict.p?dl=1",
+        "/data/gpt2/gpt_0.5.pth":"https://www.dropbox.com/s/r1icj5ytplfhuj0/gpt_0.5.pth?dl=1",
+        "/data/gpt2/labels_dict_gpt.csv":"hthttps://www.dropbox.com/s/hbxs4hp5v2y2i96/labels_dict_gpt.csv?dl=1",
         "/data/gpt2/nyt-theme-tags.csv":"https://www.dropbox.com/s/c1wts9knu3htzch/nyt-theme-tags.csv?dl=1",
     }
 
@@ -62,7 +63,7 @@ def download(model=None):
         "/data/gpt2",
     ]
     for dir in dirs:
-        if (model is None or model in dir):
+        if (model is None or model == dir.split("/")[-1]):
             try:
                 os.mkdir(pwd + dir)
             except FileExistsError:
@@ -70,11 +71,11 @@ def download(model=None):
 
     # download the files
     for sink, source in urls.items():
-        if (model is None or model in sink):
+        if (model is None or model == sink.split("/")[-1]):
             print("Downloading " + sink + " from " + source)
             try:
-                with TqdmUpTo(unit='B', unit_scale=True, miniters=1, desc=url.split('/')[-1]) as t:  # all optional kwargs
+                with TqdmUpTo(unit='B', unit_scale=True, miniters=1, desc=source.split('/')[-1]) as t:  # all optional kwargs
                     urlretrieve(source, filename=pwd+sink, reporthook=t.update_to, data=None)
                     t.total = t.n
             except urllib.error.ContentTooShortError:
-                print("Download incomplete?")
\ No newline at end of file
+                print("Download incomplete? Please try again.")
\ No newline at end of file
